FAQ
===

Why does manipulating widgets create duplicate figures?
-------------------------------------------------------

Please update your dependencies: versions of the `ipython` dependency older than 7.10.0 are known to cause this problem.

Why are there odd line breaks after inline maths in paragraphs?
---------------------------------------------------------------

This is a known issue when using Safari; try using Chrome or Firefox instead.
